==> Morpho-0.2.tar.gz: Morpho-0.2/src/jp/morpho/webapp/servlet/jsp/tagext/html/ImageTag.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

import javax.servlet.jsp.JspException;

/**
 * <P>
 * եХܥޤ
 * src °ͤǥܥ URI ꤷޤ
 * θԤ alt °ˤäƲإƥȤ󶡤ɬפޤ
 * </P>
 * <P>
 * 򥯥å뤿˥ݥƥ󥰥ǥХȤ줿硢եबФȶ˥åκɸФϤޤ
 * x ɸͤϲκ¦ԥñ̤Ƿפ졢y ɸͤϲξ¦ԥñ̤Ƿפޤ
 * Фǡˤϡname.x=x-valueפȡname.y=y-valueפޤޤ졢 "name"  name °͡x-value  y-value ϳơ x  y ɸͤǤ
 * </P>
 * @author Kumiko Hiroi
 */
public class ImageTag
	extends InputTag
{

	/**
	 * <P>
	 * ImageTag ޤ
	 * </P>
	 */
	public ImageTag()
	{
		super();
	}

	/**
	 * <P>
	 * ΥΥפ֤ޤ
	 * </P>
	 * @return ΥΥ
	 * @see jp.morpho.webapp.servlet.jsp.tagext.TagTemplate#getTagType()
	 */
	public String getTagType()
	{
		return "jp.morpho.webapp.servlet.jsp.tagext.html.ImageTag";
	}

	/**
	 * <P>
	 * ϥνǤ
	 * </P>
	 * @return EVAL_BODY_BUFFERED
	 * @see javax.servlet.jsp.tagext.Tag#doStartTag()
	 */
	public int doStartTag() throws JspException
	{
		this.setType("image");
		return super.doStartTag();
	}

}

==> Morpho-1.0.1.tar.gz: Morpho-1.0.1/src/jp/morpho/webapp/servlet/jsp/tagext/html/ImageTag.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

import javax.servlet.jsp.JspException;

/**
 * <P>
 * OtBJȒo{^쐬܂B
 * src lŃ{^𑕏摜 URI w肵܂B
 * ANZXlA҂ alt ɂĉ摜̑փeLXg񋟂Kv܂B
 * </P>
 * <P>
 * 摜NbN邽߂Ƀ|CeBOfoCXgꂽꍇAtH[oƋɃNbNn_̍WT[oɓn܂B
 * x Wl͉摜̍sNZPʂŌvAy Wl͉摜̏㑤sNZPʂŌv܂B
 * of[^ɂ́uname.x=x-valuevƁuname.y=y-valuev܂܂A "name"  name ̒lAx-value  y-value ͊eX x E y W̒lłB
 * </P>
 * @author Kumiko Hiroi
 */
public class ImageTag
	extends InputTag
{

	/**
	 * <P>
	 * ImageTag 쐬܂B
	 * </P>
	 */
	public ImageTag()
	{
		super();
	}

	/**
	 * <P>
	 * ̃^Õ^CvԂ܂B
	 * </P>
	 * @return ̃^Õ^Cv
	 * @see jp.morpho.webapp.servlet.jsp.tagext.TagTemplate#getTagType()
	 */
	public String getTagType()
	{
		return "jp.morpho.webapp.servlet.jsp.tagext.html.ImageTag";
	}

	/**
	 * <P>
	 * Jn^ȌłB
	 * </P>
	 * @return EVAL_BODY_BUFFERED
	 * @see javax.servlet.jsp.tagext.Tag#doStartTag()
	 */
	public int doStartTag() throws JspException
	{
		this.setType("image");
		return super.doStartTag();
	}

}
